@@ -36,9 +36,10 @@ from azure.storage.blob import BlobClient
 from locust.exception import StopUser
 from locust.env import Environment
 
+from grizzly.types import RequestMethod, GrizzlyResponse, RequestType
+
 from . import logger
 from .base import GrizzlyUser
-from ..types import RequestMethod, GrizzlyResponse, RequestType
 from ..tasks import RequestTask
 from ..utils import merge_dicts
 
